//
//  PokktManager.h
//  ObjectiveCTask
//
//  Created by Subhendu Sekhar Sahu on 01/07/16.
//  Copyright © 2016 Pokkt. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "PokktConfig.h"
#import "AdDelegate.h"
#import "NetworkModel.h"
#import "InAppPurchaseDetails.h"
#import "PokktInitDelegate.h"

/*!
 @abstract
 This is the main class of POKKT SDK. Developer application can interact with SDK via this
 class since SDK functionality are exposed by PokktManager.
 Developers should not try to access other SDK APIs directly.
 */

@interface PokktManager : NSObject


/*!
 @abstract
 This method initialises POKKT SDK and it should not be called again and again.
 
 This method sends a callback with POKKT SDK init result.
 
 @param pokktConfig {@link PokktConfig}
 
 Checks whether Application has all the necessary permission to proceed further.
 
 It then checks whether the application has all the SDK resource.
 
 Checks whether google play services are available.
 
 It uses PokktConfig object to initialise Store and UserDetails.
 
 Then it starts the session.
 
 It then fetches the network list from server.
 
 initPokkt will not be called again once initialized.
 
 This function sends a callback of PokktInitialised via delegate.
 
 */

+ (void)initPokkt: (PokktConfig *)pokktConfig;

/*!
 @abstract
 This method is used to update PokktConfig if needed. Normally it is not needed by developers.
 
 @param pokktConfig {@link PokktConfig}
 */

+ (void)updatePokktConfig:(PokktConfig *)pokktConfig;

/*!
 @abstract
 Set the Ad Delegate
 
 @param adDelegate Ad Delegate for the initPokkt instance
 
 @discussion Call this before calling initPokkt. SDK uses this delegate to communicate to your app and notifies the status of ads, such as an ad has been cached or failed, ad watched
 completely or skipped and ad availability status.
 
 */

+ (void)setAdDelegate:(id <AdDelegate>)adDelegate;

/*!
 @abstract
 Set the PokktInit Delegate
 
 @param initDelegate PokktInit Delegate for the initPokkt instance
 
 @discussion Call this before calling initPokkt. SDK uses this delegate to communicate to your app and notifies the status of POKKT Initiatisation.
 */

+ (void)setInitDelegate:(id <PokktInitDelegate>)initDelegate;

/*!
 @abstract
 Returns the version of the POKKT SDK.
 */

+ (NSString *)getSDKVersion;

/*!
 @abstract
 Returns the debug enable status of the POKKT SDK.
 */

+ (BOOL)isDebugEnabled;

/*!
 @abstract
 This method enables/disables the debug logging done by SDK.
 
 by default, logging is off.
 
 @param isDebug true if debug on else false
 */

+ (void)setDebug:(BOOL)isDebug;

/*!
 @abstract
 This method can be used by developer to check if there is any ad cached for a particular adConfig and is available to show.
 
 It only works if pokktManager is initialised successfully.
 
 @param adConfig {@link AdConfig}
 */

+ (void)checkAdAvailability:(AdConfig *)adConfig;

/*!
 @abstract
 This method can be used by developer to get the virtual coins available for the  cached ad of a particular adConfig.
 
 It only works if PokktManager is initialised successfully.
 
 @param adConfig {@link AdConfig}
 
 @return ad coin value Default is 0
 */

+ (float)getRewardedAdVc:(AdConfig *)adConfig;

/*!
 @abstract
 This method will be used to show an ad of a particular adConfig.
 Developer should call checkAdAvailability to check if any ad is available to show.
 It only works if pokktManager is initialised successfully.
 
 @param viewController The UIViewController in which you will display the ad. Must not be `nil`. This is required so that the ad can present additional view controllers if the user interacts with it.
 @param adConfig {@link AdConfig}
 */

+ (void)showAd:(AdConfig *)adConfig viewController:(UIViewController *)viewController;

/*!
 @abstract
 This method sends the developer app installation information to POKKT server.
 Developer has to call this method only once when his application installs on device.
 Pokktmanager init should be called before calling this method.
 
 */

+ (void)notifyAppInstall;

/*!
 @abstract
 This exposed method let developers export POKKT SDK log to iCloud.
 
 @param containerIdentifier The containerIdentifier is
 [NSString stringWithFormat:@"iCloud.%@", applicationIdentifier], , where application identifier
 is the calling process' application-identifier (com.apple.application-identifier on OS X) entitlement.
  */

+ (void)exportLogtoiCloud:(NSString *)containerIdentifier;

/*!
 @abstract
 This function returns the caching timeout of the particular network.
 After timeout, next network caching will be tried.
 
 @param networkModel {@link NetworkModel}
 @return Timeout
 */

+ (double)getCachingTimeoutDuration:(NetworkModel *)networkModel;

/*!
 @abstract
 This is an utility method to show toast.
 
 @param viewController The UIViewController in which you will display the toast message. Must not be `nil`.
 @param message Message to show
 */

+ (void)showToast:(NSString *)message viewController:(UIViewController *)viewController;

/*!
 @abstract
 This method is called by developer to send any in-app purchase information to Pokkt.
 
 @param inAppPurchaseDetails {@link InAppPurchaseDetails}
 */

+ (void)trackIAP:(InAppPurchaseDetails *)inAppPurchaseDetails;

/*!
 @abstract
 Use to add log in logfile.
 
 @param message text message
 */

+(void)printLog:(NSString *)message;

@end
